@@ -25,5 +25,7 @@ parsers.PROTOCOL_PARSERS.update({
     'computing': ComputingQueryParser,
     'script': parsers.QueryParser,
     'rdb': parsers.QueryParser,
-    'nas': parsers.QueryParser
+    'nas': parsers.QueryParser,
+    'ess': parsers.QueryParser,
+    'dns': parsers.RestXMLParser
 })
